@@ -19,7 +19,7 @@ use Types::Standard qw( is_CodeRef Value Object Ref );
 
 use namespace::autoclean;
 
-our $VERSION = 'v0.5.2';
+our $VERSION = 'v0.5.3';
 
 
 sub import {
@@ -100,13 +100,20 @@ sub _process_has {
                     }
                 }
 
+                $opts{is} = $once ? 'rw' : 'ro';
 
-                if ($opts{trigger} && ($is ne "once")) {
-                    croak "triggers are not applicable to const attributes";
-                }
+            }
 
-                $opts{is}  = $once ? 'rw' : 'ro';
+            if ($opts{trigger} && ($is ne "once")) {
+                croak "triggers are not applicable to const attributes";
+            }
 
+            if ($opts{writer} && ($is ne "once")) {
+                croak "writers are not applicable to const attributes";
+            }
+
+            if ($opts{clearer}) {
+                croak "clearers are not applicable to const attributes";
             }
 
         }
@@ -136,7 +143,7 @@ MooX::Const - Syntactic sugar for constant and write-once Moo attributes
 
 =head1 VERSION
 
-version v0.5.2
+version v0.5.3
 
 =head1 SYNOPSIS
 
